@@ -699,157 +699,156 @@ jsSurveyExtAddin <- function(nfactor.limit = 20, max.filesize = 2048) {
     ),
     inverse = TRUE,
     tabPanel("Data",
-             icon = icon("table"),
-             sidebarLayout(
-               sidebarPanel(
-                 uiOutput("import"),
-                 downloadButton("downloadData", "Example data")
-               ),
-               mainPanel(
-                 tabsetPanel(
-                   type = "pills",
-                   tabPanel("Data", withLoader(DTOutput("data"), type = "html", loader = "loader6")),
-                   tabPanel("Label", withLoader(DTOutput("data_label", width = "100%"), type = "html", loader = "loader6"))
-                 ),
-                 htmlOutput("naomit")
-               )
-             )
+      icon = icon("table"),
+      sidebarLayout(
+        sidebarPanel(
+          uiOutput("import"),
+          downloadButton("downloadData", "Example data")
+        ),
+        mainPanel(
+          tabsetPanel(
+            type = "pills",
+            tabPanel("Data", withLoader(DTOutput("data"), type = "html", loader = "loader6")),
+            tabPanel("Label", withLoader(DTOutput("data_label", width = "100%"), type = "html", loader = "loader6"))
+          ),
+          htmlOutput("naomit")
+        )
+      )
     ),
     tabPanel("Table 1",
-             icon = icon("percentage"),
-             sidebarLayout(
-               sidebarPanel(
-                 tb1moduleUI("tb1")
-               ),
-               mainPanel(
-                 tabsetPanel(
-                   type = "pills",
-                   tabPanel(
-                     "Unweighted",
-                     downloadButton(outputId = "dl.untable1", style = "display:none;"),
-                     actionButton("dl.untable1.clk", NULL, style = "display:none;"),
-                     withLoader(DTOutput("untable1"), type = "html", loader = "loader6"),
-                     wellPanel(
-                       h5("Normal continuous variables  are summarized with Mean (SD) and t-test(2 groups) or ANOVA(> 2 groups)"),
-                       h5("Non-normal continuous variables are summarized with median [IQR or min,max] and kruskal-wallis test"),
-                       h5("Categorical variables  are summarized with table")
-                     )
-                   ),
-                   tabPanel(
-                     "Weighted",
-                     downloadButton(outputId = "dl.table1", style = "display:none;"),
-                     actionButton("dl.table1.clk", NULL, style = "display:none;"),
-                     withLoader(DTOutput("table1"), type = "html", loader = "loader6"),
-                     wellPanel(
-                       h5("Normal continuous variables  are summarized with Mean (SD) and complex survey regression"),
-                       h5("Non-normal continuous variables are summarized with median [IQR or min,max] and complex sampling rank test"),
-                       h5("Categorical variables  are summarized with table and svychisq test")
-                     )
-                   )
-                 )
-               )
-             )
+      icon = icon("percentage"),
+      sidebarLayout(
+        sidebarPanel(
+          tb1moduleUI("tb1")
+        ),
+        mainPanel(
+          tabsetPanel(
+            type = "pills",
+            tabPanel(
+              "Unweighted",
+              downloadButton(outputId = "dl.untable1", style = "display:none;"),
+              actionButton("dl.untable1.clk", NULL, style = "display:none;"),
+              withLoader(DTOutput("untable1"), type = "html", loader = "loader6"),
+              wellPanel(
+                h5("Normal continuous variables  are summarized with Mean (SD) and t-test(2 groups) or ANOVA(> 2 groups)"),
+                h5("Non-normal continuous variables are summarized with median [IQR or min,max] and kruskal-wallis test"),
+                h5("Categorical variables  are summarized with table")
+              )
+            ),
+            tabPanel(
+              "Weighted",
+              downloadButton(outputId = "dl.table1", style = "display:none;"),
+              actionButton("dl.table1.clk", NULL, style = "display:none;"),
+              withLoader(DTOutput("table1"), type = "html", loader = "loader6"),
+              wellPanel(
+                h5("Normal continuous variables  are summarized with Mean (SD) and complex survey regression"),
+                h5("Non-normal continuous variables are summarized with median [IQR or min,max] and complex sampling rank test"),
+                h5("Categorical variables  are summarized with table and svychisq test")
+              )
+            )
+          )
+        )
+      )
     ),
     navbarMenu("Survey regression",
-               icon = icon("list-alt"),
-               tabPanel(
-                 "Linear",
-                 sidebarLayout(
-                   sidebarPanel(
-                     regressModuleUI("linear")
-                   ),
-                   mainPanel(
-                     downloadButton(outputId = "dl.linreg", style = "display:none;"),
-                     actionButton("dl.linreg.clk", NULL, style = "display:none;"),
-                     withLoader(DTOutput("lineartable"), type = "html", loader = "loader6")
-                   )
-                 )
-               ),
-               tabPanel(
-                 "Binomial",
-                 sidebarLayout(
-                   sidebarPanel(
-                     regressModuleUI("logistic")
-                   ),
-                   mainPanel(
-                     downloadButton(outputId = "dl.logreg", style = "display:none;"),
-                     actionButton("dl.logreg.clk", NULL, style = "display:none;"),
-                     withLoader(DTOutput("logistictable"), type = "html", loader = "loader6")
-                   )
-                 )
-               ),
-               tabPanel(
-                 "Cox model",
-                 sidebarLayout(
-                   sidebarPanel(
-                     coxUI("cox")
-                   ),
-                   mainPanel(
-                     downloadButton(outputId = "dl.coxreg", style = "display:none;"),
-                     actionButton("dl.coxreg.clk", NULL, style = "display:none;"),
-                     withLoader(DTOutput("coxtable"), type = "html", loader = "loader6")
-                   )
-                 )
-               )
+      icon = icon("list-alt"),
+      tabPanel(
+        "Linear",
+        sidebarLayout(
+          sidebarPanel(
+            regressModuleUI("linear")
+          ),
+          mainPanel(
+            downloadButton(outputId = "dl.linreg", style = "display:none;"),
+            actionButton("dl.linreg.clk", NULL, style = "display:none;"),
+            withLoader(DTOutput("lineartable"), type = "html", loader = "loader6")
+          )
+        )
+      ),
+      tabPanel(
+        "Binomial",
+        sidebarLayout(
+          sidebarPanel(
+            regressModuleUI("logistic")
+          ),
+          mainPanel(
+            downloadButton(outputId = "dl.logreg", style = "display:none;"),
+            actionButton("dl.logreg.clk", NULL, style = "display:none;"),
+            withLoader(DTOutput("logistictable"), type = "html", loader = "loader6")
+          )
+        )
+      ),
+      tabPanel(
+        "Cox model",
+        sidebarLayout(
+          sidebarPanel(
+            coxUI("cox")
+          ),
+          mainPanel(
+            downloadButton(outputId = "dl.coxreg", style = "display:none;"),
+            actionButton("dl.coxreg.clk", NULL, style = "display:none;"),
+            withLoader(DTOutput("coxtable"), type = "html", loader = "loader6")
+          )
+        )
+      )
     ),
     navbarMenu("Plot",
-               icon = icon("chart-column"),
-               tabPanel(
-                 "Scatter plot",
-                 sidebarLayout(
-                   sidebarPanel(
-                     ggpairsModuleUI1("ggpairs")
-                   ),
-                   mainPanel(
-                     withLoader(plotOutput("ggpairs_plot"), type = "html", loader = "loader6"),
-                     ggpairsModuleUI2("ggpairs")
-                   )
-                 )
-               ),
-               tabPanel(
-                 "Kaplan-meier plot",
-                 sidebarLayout(
-                   sidebarPanel(
-                     kaplanUI("kaplan")
-                   ),
-                   mainPanel(
-                     optionUI("kaplan"),
-                     withLoader(plotOutput("kaplan_plot"), type = "html", loader = "loader6"),
-                     ggplotdownUI("kaplan")
-                   )
-                 )
-               )
+      icon = icon("chart-column"),
+      tabPanel(
+        "Scatter plot",
+        sidebarLayout(
+          sidebarPanel(
+            ggpairsModuleUI1("ggpairs")
+          ),
+          mainPanel(
+            withLoader(plotOutput("ggpairs_plot"), type = "html", loader = "loader6"),
+            ggpairsModuleUI2("ggpairs")
+          )
+        )
+      ),
+      tabPanel(
+        "Kaplan-meier plot",
+        sidebarLayout(
+          sidebarPanel(
+            kaplanUI("kaplan")
+          ),
+          mainPanel(
+            optionUI("kaplan"),
+            withLoader(plotOutput("kaplan_plot"), type = "html", loader = "loader6"),
+            ggplotdownUI("kaplan")
+          )
+        )
+      )
     ),
     navbarMenu("ROC analysis",
-               icon = icon("check"),
-               tabPanel(
-                 "ROC",
-                 sidebarLayout(
-                   sidebarPanel(
-                     rocUI("roc")
-                   ),
-                   mainPanel(
-                     withLoader(plotOutput("plot_roc"), type = "html", loader = "loader6"),
-                     ggplotdownUI("roc"),
-                     withLoader(DTOutput("table_roc"), type = "html", loader = "loader6")
-                   )
-                 )
-               ),
-               tabPanel(
-                 "Time-dependent ROC",
-                 sidebarLayout(
-                   sidebarPanel(
-                     timerocUI("timeroc")
-                   ),
-                   mainPanel(
-                     withLoader(plotOutput("plot_timeroc"), type = "html", loader = "loader6"),
-                     ggplotdownUI("timeroc"),
-                     withLoader(DTOutput("table_timeroc"), type = "html", loader = "loader6")
-                   )
-                 )
-               )
+      icon = icon("check"),
+      tabPanel(
+        "ROC",
+        sidebarLayout(
+          sidebarPanel(
+            rocUI("roc")
+          ),
+          mainPanel(
+            withLoader(plotOutput("plot_roc"), type = "html", loader = "loader6"),
+            ggplotdownUI("roc"),
+            withLoader(DTOutput("table_roc"), type = "html", loader = "loader6")
+          )
+        )
+      ),
+      tabPanel(
+        "Time-dependent ROC",
+        sidebarLayout(
+          sidebarPanel(
+            timerocUI("timeroc")
+          ),
+          mainPanel(
+            withLoader(plotOutput("plot_timeroc"), type = "html", loader = "loader6"),
+            ggplotdownUI("timeroc"),
+            withLoader(DTOutput("table_timeroc"), type = "html", loader = "loader6")
+          )
+        )
+      )
     ),
-
     navbarMenu(
       title = "Subgroup analysis",
       icon = icon("chart-bar"),
@@ -956,15 +955,15 @@ jsSurveyExtAddin <- function(nfactor.limit = 20, max.filesize = 2048) {
 
     output$data <- renderDT({
       datatable(data(),
-                rownames = F, editable = F, extensions = "Buttons", caption = "Data",
-                options = c(opt.data("data"), list(scrollX = TRUE))
+        rownames = F, editable = F, extensions = "Buttons", caption = "Data",
+        options = c(opt.data("data"), list(scrollX = TRUE))
       )
     })
 
     output$data_label <- renderDT({
       datatable(data.label(),
-                rownames = F, editable = F, extensions = "Buttons", caption = "Label of data",
-                options = c(opt.data("label"), list(scrollX = TRUE))
+        rownames = F, editable = F, extensions = "Buttons", caption = "Label of data",
+        options = c(opt.data("label"), list(scrollX = TRUE))
       )
     })
 
@@ -986,13 +985,13 @@ jsSurveyExtAddin <- function(nfactor.limit = 20, max.filesize = 2048) {
         tb <- cbind(rn, data.frame(tb))
         colnames(tb)[1] <- " "
 
-        officer::read_docx() |>
+        officer::read_docx() %>%
           body_add_flextable(
             tb %>%
               flextable() %>%
               autofit() %>%
               theme_booktabs(bold_header = TRUE)
-          ) |>
+          ) %>%
           print(target = file)
       }
     )
@@ -1003,42 +1002,42 @@ jsSurveyExtAddin <- function(nfactor.limit = 20, max.filesize = 2048) {
       tb <- out_untb1()$table
       cap <- out_untb1()$caption
       out.tb1 <- datatable(tb,
-                           rownames = T, extensions = "Buttons", caption = cap,
-                           options = c(
-                             list(
-                               dom = "<lf<rt>Bip>",
-                               lengthMenu = list(
-                                 c(10, 25, -1),
-                                 c("10", "25", "All")
-                               ),
-                               pageLength = 25,
-                               ordering = F,
-                               buttons = list(
-                                 "copy",
-                                 "print",
-                                 list(
-                                   text = "Download",
-                                   extend = "collection",
-                                   buttons = list(
-                                     list(extend = "csv", filename = "tb1"),
-                                     list(extend = "excel", filename = "tb1"),
-                                     list(extend = "pdf", filename = "tb1")
-                                   ) # ,
-                                 ),
-                                 list(
-                                   text = "Word",
-                                   extend = "collection",
-                                   action = DT::JS(
-                                     "function ( e, dt, node, config ) {
+        rownames = T, extensions = "Buttons", caption = cap,
+        options = c(
+          list(
+            dom = "<lf<rt>Bip>",
+            lengthMenu = list(
+              c(10, 25, -1),
+              c("10", "25", "All")
+            ),
+            pageLength = 25,
+            ordering = F,
+            buttons = list(
+              "copy",
+              "print",
+              list(
+                text = "Download",
+                extend = "collection",
+                buttons = list(
+                  list(extend = "csv", filename = "tb1"),
+                  list(extend = "excel", filename = "tb1"),
+                  list(extend = "pdf", filename = "tb1")
+                ) # ,
+              ),
+              list(
+                text = "Word",
+                extend = "collection",
+                action = DT::JS(
+                  "function ( e, dt, node, config ) {
                   Shiny.setInputValue('dl.untable1.clk', true, {priority: 'event'});
                   }"
-                                   )
-                                 )
-                               )
-                             ),
-                             list(columnDefs = list(list(visible = FALSE, targets = which(colnames(tb) %in% c("test", "sig"))))),
-                             list(scrollX = TRUE)
-                           )
+                )
+              )
+            )
+          ),
+          list(columnDefs = list(list(visible = FALSE, targets = which(colnames(tb) %in% c("test", "sig"))))),
+          list(scrollX = TRUE)
+        )
       )
       if ("sig" %in% colnames(tb)) {
         out.tb1 <- out.tb1 %>% formatStyle("sig", target = "row", backgroundColor = styleEqual("**", "yellow"))
@@ -1060,13 +1059,13 @@ jsSurveyExtAddin <- function(nfactor.limit = 20, max.filesize = 2048) {
         tb <- cbind(rn, data.frame(tb))
         colnames(tb)[1] <- " "
 
-        officer::read_docx() |>
+        officer::read_docx() %>%
           body_add_flextable(
             tb %>%
               flextable() %>%
               autofit() %>%
               theme_booktabs(bold_header = TRUE)
-          ) |>
+          ) %>%
           print(target = file)
       }
     )
@@ -1077,42 +1076,42 @@ jsSurveyExtAddin <- function(nfactor.limit = 20, max.filesize = 2048) {
       tb <- out_tb1()$table
       cap <- out_tb1()$caption
       out.tb1 <- datatable(tb,
-                           rownames = T, extensions = "Buttons", caption = cap,
-                           options = c(
-                             list(
-                               dom = "<lf<rt>Bip>",
-                               lengthMenu = list(
-                                 c(10, 25, -1),
-                                 c("10", "25", "All")
-                               ),
-                               pageLength = 25,
-                               ordering = F,
-                               buttons = list(
-                                 "copy",
-                                 "print",
-                                 list(
-                                   text = "Download",
-                                   extend = "collection",
-                                   buttons = list(
-                                     list(extend = "csv", filename = "tb1"),
-                                     list(extend = "excel", filename = "tb1"),
-                                     list(extend = "pdf", filename = "tb1")
-                                   ) # ,
-                                 ),
-                                 list(
-                                   text = "Word",
-                                   extend = "collection",
-                                   action = DT::JS(
-                                     "function ( e, dt, node, config ) {
+        rownames = T, extensions = "Buttons", caption = cap,
+        options = c(
+          list(
+            dom = "<lf<rt>Bip>",
+            lengthMenu = list(
+              c(10, 25, -1),
+              c("10", "25", "All")
+            ),
+            pageLength = 25,
+            ordering = F,
+            buttons = list(
+              "copy",
+              "print",
+              list(
+                text = "Download",
+                extend = "collection",
+                buttons = list(
+                  list(extend = "csv", filename = "tb1"),
+                  list(extend = "excel", filename = "tb1"),
+                  list(extend = "pdf", filename = "tb1")
+                ) # ,
+              ),
+              list(
+                text = "Word",
+                extend = "collection",
+                action = DT::JS(
+                  "function ( e, dt, node, config ) {
                   Shiny.setInputValue('dl.table1.clk', true, {priority: 'event'});
                   }"
-                                   )
-                                 )
-                               )
-                             ),
-                             list(columnDefs = list(list(visible = FALSE, targets = which(colnames(tb) %in% c("test", "sig"))))),
-                             list(scrollX = TRUE)
-                           )
+                )
+              )
+            )
+          ),
+          list(columnDefs = list(list(visible = FALSE, targets = which(colnames(tb) %in% c("test", "sig"))))),
+          list(scrollX = TRUE)
+        )
       )
       if ("sig" %in% colnames(tb)) {
         out.tb1 <- out.tb1 %>% formatStyle("sig", target = "row", backgroundColor = styleEqual("**", "yellow"))
@@ -1135,13 +1134,13 @@ jsSurveyExtAddin <- function(nfactor.limit = 20, max.filesize = 2048) {
         tb <- cbind(rn, data.frame(tb))
         colnames(tb) <- c(" ", cn)
 
-        officer::read_docx() |>
+        officer::read_docx() %>%
           body_add_flextable(
             tb %>%
               flextable() %>%
               autofit() %>%
               theme_booktabs(bold_header = TRUE)
-          ) |>
+          ) %>%
           print(target = file)
       }
     )
@@ -1151,42 +1150,42 @@ jsSurveyExtAddin <- function(nfactor.limit = 20, max.filesize = 2048) {
     output$lineartable <- renderDT({
       hide <- which(colnames(out_linear()$table) == "sig")
       datatable(out_linear()$table,
-                rownames = T, extensions = "Buttons", caption = out_linear()$caption,
-                options = c(
-                  list(
-                    dom = "<lf<rt>Bip>",
-                    lengthMenu = list(
-                      c(10, 25, -1),
-                      c("10", "25", "All")
-                    ),
-                    pageLength = 25,
-                    ordering = F,
-                    buttons = list(
-                      "copy",
-                      "print",
-                      list(
-                        text = "Download",
-                        extend = "collection",
-                        buttons = list(
-                          list(extend = "csv", filename = out_linear()$caption),
-                          list(extend = "excel", filename = out_linear()$caption),
-                          list(extend = "pdf", filename = out_linear()$caption)
-                        ) # ,
-                      ),
-                      list(
-                        text = "Word",
-                        extend = "collection",
-                        action = DT::JS(
-                          "function ( e, dt, node, config ) {
+        rownames = T, extensions = "Buttons", caption = out_linear()$caption,
+        options = c(
+          list(
+            dom = "<lf<rt>Bip>",
+            lengthMenu = list(
+              c(10, 25, -1),
+              c("10", "25", "All")
+            ),
+            pageLength = 25,
+            ordering = F,
+            buttons = list(
+              "copy",
+              "print",
+              list(
+                text = "Download",
+                extend = "collection",
+                buttons = list(
+                  list(extend = "csv", filename = out_linear()$caption),
+                  list(extend = "excel", filename = out_linear()$caption),
+                  list(extend = "pdf", filename = out_linear()$caption)
+                ) # ,
+              ),
+              list(
+                text = "Word",
+                extend = "collection",
+                action = DT::JS(
+                  "function ( e, dt, node, config ) {
                   Shiny.setInputValue('dl.linreg.clk', true, {priority: 'event'});
                   }"
-                        )
-                      )
-                    )
-                  ),
-                  list(columnDefs = list(list(visible = FALSE, targets = hide))),
-                  list(scrollX = TRUE)
                 )
+              )
+            )
+          ),
+          list(columnDefs = list(list(visible = FALSE, targets = hide))),
+          list(scrollX = TRUE)
+        )
       ) %>% formatStyle("sig", target = "row", backgroundColor = styleEqual("**", "yellow"))
     })
 
@@ -1205,13 +1204,13 @@ jsSurveyExtAddin <- function(nfactor.limit = 20, max.filesize = 2048) {
         tb <- cbind(rn, data.frame(tb))
         colnames(tb) <- c(" ", cn)
 
-        officer::read_docx() |>
+        officer::read_docx() %>%
           body_add_flextable(
             tb %>%
               flextable() %>%
               autofit() %>%
               theme_booktabs(bold_header = TRUE)
-          ) |>
+          ) %>%
           print(target = file)
       }
     )
@@ -1221,42 +1220,42 @@ jsSurveyExtAddin <- function(nfactor.limit = 20, max.filesize = 2048) {
     output$logistictable <- renderDT({
       hide <- which(colnames(out_logistic()$table) == "sig")
       datatable(out_logistic()$table,
-                rownames = T, extensions = "Buttons", caption = out_logistic()$caption,
-                options = c(
-                  list(
-                    dom = "<lf<rt>Bip>",
-                    lengthMenu = list(
-                      c(10, 25, -1),
-                      c("10", "25", "All")
-                    ),
-                    pageLength = 25,
-                    ordering = F,
-                    buttons = list(
-                      "copy",
-                      "print",
-                      list(
-                        text = "Download",
-                        extend = "collection",
-                        buttons = list(
-                          list(extend = "csv", filename = out_logistic()$caption),
-                          list(extend = "excel", filename = out_logistic()$caption),
-                          list(extend = "pdf", filename = out_logistic()$caption)
-                        ) # ,
-                      ),
-                      list(
-                        text = "Word",
-                        extend = "collection",
-                        action = DT::JS(
-                          "function ( e, dt, node, config ) {
+        rownames = T, extensions = "Buttons", caption = out_logistic()$caption,
+        options = c(
+          list(
+            dom = "<lf<rt>Bip>",
+            lengthMenu = list(
+              c(10, 25, -1),
+              c("10", "25", "All")
+            ),
+            pageLength = 25,
+            ordering = F,
+            buttons = list(
+              "copy",
+              "print",
+              list(
+                text = "Download",
+                extend = "collection",
+                buttons = list(
+                  list(extend = "csv", filename = out_logistic()$caption),
+                  list(extend = "excel", filename = out_logistic()$caption),
+                  list(extend = "pdf", filename = out_logistic()$caption)
+                ) # ,
+              ),
+              list(
+                text = "Word",
+                extend = "collection",
+                action = DT::JS(
+                  "function ( e, dt, node, config ) {
                   Shiny.setInputValue('dl.logreg.clk', true, {priority: 'event'});
                   }"
-                        )
-                      )
-                    )
-                  ),
-                  list(columnDefs = list(list(visible = FALSE, targets = hide))),
-                  list(scrollX = TRUE)
                 )
+              )
+            )
+          ),
+          list(columnDefs = list(list(visible = FALSE, targets = hide))),
+          list(scrollX = TRUE)
+        )
       ) %>% formatStyle("sig", target = "row", backgroundColor = styleEqual("**", "yellow"))
     })
 
@@ -1275,13 +1274,13 @@ jsSurveyExtAddin <- function(nfactor.limit = 20, max.filesize = 2048) {
         tb <- cbind(rn, data.frame(tb))
         colnames(tb) <- c(" ", cn)
 
-        officer::read_docx() |>
+        officer::read_docx() %>%
           body_add_flextable(
             tb %>%
               flextable() %>%
               autofit() %>%
               theme_booktabs(bold_header = TRUE)
-          ) |>
+          ) %>%
           print(target = file)
       }
     )
@@ -1291,41 +1290,41 @@ jsSurveyExtAddin <- function(nfactor.limit = 20, max.filesize = 2048) {
     output$coxtable <- renderDT({
       hide <- which(colnames(out_cox()$table) == c("sig"))
       datatable(out_cox()$table,
-                rownames = T, extensions = "Buttons", caption = out_cox()$caption,
-                options = c(
-                  list(
-                    dom = "<lf<rt>Bip>",
-                    lengthMenu = list(
-                      c(10, 25, -1),
-                      c("10", "25", "All")
-                    ),
-                    pageLength = 25,
-                    ordering = F,
-                    buttons = list(
-                      "copy",
-                      "print",
-                      list(
-                        text = "Download",
-                        extend = "collection",
-                        buttons = list(
-                          list(extend = "csv", filename = out_cox()$caption),
-                          list(extend = "excel", filename = out_cox()$caption),
-                          list(extend = "pdf", filename = out_cox()$caption)
-                        ) # ,
-                      ),
-                      list(
-                        text = "Word",
-                        extend = "collection",
-                        action = DT::JS(
-                          "function ( e, dt, node, config ) {
+        rownames = T, extensions = "Buttons", caption = out_cox()$caption,
+        options = c(
+          list(
+            dom = "<lf<rt>Bip>",
+            lengthMenu = list(
+              c(10, 25, -1),
+              c("10", "25", "All")
+            ),
+            pageLength = 25,
+            ordering = F,
+            buttons = list(
+              "copy",
+              "print",
+              list(
+                text = "Download",
+                extend = "collection",
+                buttons = list(
+                  list(extend = "csv", filename = out_cox()$caption),
+                  list(extend = "excel", filename = out_cox()$caption),
+                  list(extend = "pdf", filename = out_cox()$caption)
+                ) # ,
+              ),
+              list(
+                text = "Word",
+                extend = "collection",
+                action = DT::JS(
+                  "function ( e, dt, node, config ) {
                   Shiny.setInputValue('dl.coxreg.clk', true, {priority: 'event'});
                   }"
-                        )
-                      )
-                    )
-                  ),
-                  list(columnDefs = list(list(visible = FALSE, targets = hide)))
                 )
+              )
+            )
+          ),
+          list(columnDefs = list(list(visible = FALSE, targets = hide)))
+        )
       ) %>% formatStyle("sig", target = "row", backgroundColor = styleEqual("**", "yellow"))
     })
 
@@ -1349,9 +1348,9 @@ jsSurveyExtAddin <- function(nfactor.limit = 20, max.filesize = 2048) {
 
     output$table_roc <- renderDT({
       datatable(out_roc()$tb,
-                rownames = F, editable = F, extensions = "Buttons",
-                caption = "ROC results",
-                options = c(jstable::opt.tbreg("roctable"), list(scrollX = TRUE))
+        rownames = F, editable = F, extensions = "Buttons",
+        caption = "ROC results",
+        options = c(jstable::opt.tbreg("roctable"), list(scrollX = TRUE))
       )
     })
 
@@ -1363,8 +1362,8 @@ jsSurveyExtAddin <- function(nfactor.limit = 20, max.filesize = 2048) {
 
     output$table_timeroc <- renderDT({
       datatable(out_timeroc()$tb,
-                rownames = F, editable = F, extensions = "Buttons", caption = "ROC results",
-                options = c(jstable::opt.tbreg("roctable"), list(scrollX = TRUE))
+        rownames = F, editable = F, extensions = "Buttons", caption = "ROC results",
+        options = c(jstable::opt.tbreg("roctable"), list(scrollX = TRUE))
       )
     })
 
@@ -1400,7 +1399,6 @@ jsSurveyExtAddin <- function(nfactor.limit = 20, max.filesize = 2048) {
     session$onSessionEnded(function() {
       stopApp()
     })
-
   }
   # viewer <- dialogViewer("Descriptive statistics", width = 1100, height = 850)
   viewer <- browserViewer(browser = getOption("browser"))
